import axios from "./api/index";
import {
    DateRange,
    VariableRange,
    Variable
} from "./components/types";
export let API = {
    getTargetVariables: () => axios.get("/api/target_variables"),
    getTargetRange: (data: { 
            target: string;
            dates: string[];
            selectedFilters: {
                target: string;
                filters: {
                    range: VariableRange;
                    type: "num" | "cat"
                };
            }[];
        }) =>
        axios.post("/api/target_range", data),
    getFilterRange: (data: { 
            target: string;
            dates: string[];
        }) =>
        axios.post("/api/filter_range", data),
    updateTarget: (data: { target: string; good_range: VariableRange }) =>
        axios.post("/api/update_target_range", data),
    getTargetChart: (data: {
            target: string;
            dates: string[2];
            selectedFilters: {
                target: string;
                filters: {
                    range: VariableRange;
                    type: "num" | "cat"
                };
            }[];
        }) =>
        axios.post("/api/create_target_chart", data),
    getAnalysisVariables: (target: string) =>
        axios.get(`/api/analysis_variables/${encodeURIComponent(target)}`),
    getAnalysis: (data: {
        target: string;
        bin: number;
        filters: {
            variables: string[];
            good_range: VariableRange;
            dates: string[];
        };
        selectedFilters: {
            target: string;
            filters: {
                range: VariableRange;
                type: "num" | "cat"
            };
        }[];
    }) => axios.post("/api/get_analysis", data),
    getTargetState: (data: {
        target: string;
        filters: {
            dates: string[];
            range: VariableRange;
        };
        selectedFilters: {
            target: string;
            filters: {
                range: VariableRange;
                type: "num" | "cat"
            };
        }[];
    }) => axios.post(`/api/target_state`, data),
    updateTargetState: (data: {
        target: string;
        filters: {
            dates: string[];
            range: VariableRange;
        };
        variables: {
            variable: string;
            good_range: VariableRange;
        }[];
        selectedFilters: {
            target: string;
            filters: {
                range: VariableRange;
                type: "num" | "cat"
            };
        }[];
    }) => axios.post("/api/update_target_state", data),
    saveStudy: (data: {
        study_id?: string;
        variables: Variable[];
        target_info: {
            target: string;
            target_date?: DateRange;
            target_selected_range?: VariableRange;
            target_initial_range?: VariableRange;
            target_type?: "num" | "cat";
        };
        analysis_variables: string[];
        selectedFilters: {
            target: string;
            filters: {
                range: VariableRange;
                type: "num" | "cat"
            };
        }[];
    }) => axios.post("/api/study", data),
    getStudies: () => axios.get("/api/get_studies"),
    getStudy: (studyId: string) => axios.get(`/api/study/${studyId}`),
    checkStudy: (studyId: string) => axios.get(`/api/check_study/${studyId}`),
    deleteStudy: (studyId: string) => axios.delete(`/api/study/${studyId}`),
};
